 # Simba Documentation

Simba is a Clojure-like, interpreted programming language that easily interoperates with all Python libraries.
Features:
- multimethods
- persistent immutable data structures via Pyrsistent
- easy interoperability
- macros
- Clojure-like standard library based on similar abstractions
- named arguments

Install:
You can use Simba from the command line by calling `src/simba.py` from the main directory.
You can execute some files with:
`src/simba.py <file-name> <eventual-other-file-names>*`; at which point the execution will always start in the main namespace.

Build:
